#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.9
visibility:           public
id:                   filelock-0.1.1.9-ETR6ZYppKlZHRmLOB2x6JA
key:                  filelock-0.1.1.9-ETR6ZYppKlZHRmLOB2x6JA
license:              CC0-1.0
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             https://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  5f8e98b9bcbc177fdf7f072942b46f40
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.9-ETR6ZYppKlZHRmLOB2x6JA
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

